set tcl_prompt1 {puts -nonewline "plyfilt> "}
set tcl_prompt2 {puts -nonewline "> "}

set DefaultIters 50
set DefaultLambda 0.6732
set DefaultMu -0.6307
set DefaultAlpha 0.3

proc gauss_holes args {
    global DefaultIters
    global DefaultAlpha
    
    if {[llength $args] == 0} {
	puts "Usage: gauss_holes <mesh-name> \[<iters> \[<alpha>\]\]"
	return
    }

    set mesh [lindex $args 0]
    set iters $DefaultIters
    set alpha $DefaultAlpha

    if {[llength $args] >= 2} {
	set iters [lindex $argv 1]
	if {[llength $args] == 3]} {
	    set alpha [lindex $argv 2]
	}
    }
    
    puts ""
    for {set i 0} {$i < $iters} {incr i} {
	puts -nonewline "\rFilter pass [expr $i+1] of $iters..."
	filternocon $mesh $alpha
    }
    puts ""
    plv_compnorm $mesh
    redraw
}

proc taub_holes args {
    global DefaultIters
    global DefaultLambda
    global DefaultMu

    if {[llength $args] == 0} {
	puts "Usage: taub_holes <mesh-name> \[<iters> \[<lambda> <mu>\]\]"
	return
    }

    set mesh [lindex $args 0]
    set iters $DefaultIters
    set lambda $DefaultLambda
    set mu $DefaultMu

    if {[llength $args] >= 2} {
	set iters [lindex $argv 1]
	if {[llength $args] == 4]} {
	    set lambda [lindex $argv 2]
	    set mu [lindex $argv 3]
	}
    }
    
    puts ""
    for {set i 0} {$i < $iters} {incr i} {
	puts -nonewline "\rFilter pass [expr $i+1] of $iters..."
	filternocon $mesh $lambda
	filternocon $mesh $mu
    }
    puts ""
    plv_compnorm $mesh
    redraw
}

proc gauss {mesh lambda iters} {
    
    puts ""
    for {set i 0} {$i < $iters} {incr i} {
	puts -nonewline "\rFilter pass [expr $i+1] of $iters..."
	filter $mesh $lambda
    }
    puts ""
    plv_compnorm $mesh
    redraw
}

proc taub {mesh lambda mu iters} {
    
    puts ""
    for {set i 0} {$i < $iters} {incr i} {
	puts -nonewline "\rFilter pass [expr $i+1] of $iters..."
	filter $mesh $lambda
	filter $mesh $mu
    }
    puts ""
    plv_compnorm $mesh
    redraw
}

