#!plyview

if {![info exists env(HOSTTYPE)]} {
    set env(HOSTTYPE) iris4d
}

# Creates an alias for a command name
proc alias {newname oldname} {
    eval "proc $newname args \{eval \"$oldname \$args\"\}"
}

proc donothing args {
}

set tcl_prompt1 {puts -nonewline "plyview> "}
set tcl_prompt2 {puts -nonewline "> "}

plv_material -confscale 10

set theMeshResolution 3
set thePolygonMode fill
set theShadeModel smooth
set theShinyMode 1
set theCullMode 1
set theEmissiveMode 0
set theFlipNormalMode 0
set theConfidenceMode 0
set theTrueColorMode 0
set theTextureMode 0
set theFalseColorMode 0
set isSinglebuffer 0
set isOrthographic 0
set theColorMode "graycolor"

# Prepare cut mesh - also need to make sure that these variables
# exist as arrays
set meshVisible(ClipMesh) -1
set meshFrame(ClipMesh) -1

set theMover _viewer_
set clipEnabled 0

plv_resolution $theMeshResolution
plv_drawstyle -cull $theCullMode -pointsize 3

proc writeppmframe {name count} {
    
    # Set up frame count suffix
    if {$count < 10} {
	set suffix 000${count}
    } elseif {$count < 100} {
	set suffix 00${count}
    } elseif {$count < 1000} {
	set suffix 0${count}
    } else {
	set suffix ${count}
    }

    # Write out IRIS rgb image
    writeimage ${name}${suffix}.rgb

    # Convert to ppm for mpeg usage
    exec /usr/common/bin/toppm ${name}${suffix}.rgb ${name}${suffix}.ppm

    # Remove the IRIS rgb file
    exec /bin/rm ${name}${suffix}.rgb
}

proc writeirisframe {name count} {
    
    # Set up frame count suffix
    if {$count < 10} {
	set suffix 000${count}
    } elseif {$count < 100} {
	set suffix 00${count}
    } elseif {$count < 1000} {
	set suffix 0${count}
    } else {
	set suffix ${count}
    }

    # Write out IRIS rgb image
    writeimage ${name}${suffix}.rgb
}

proc writebwframe {name count} {
    
    # Set up frame count suffix
    if {$count < 10} {
	set suffix 000${count}
    } elseif {$count < 100} {
	set suffix 00${count}
    } elseif {$count < 1000} {
	set suffix 0${count}
    } else {
	set suffix ${count}
    }

    # Write out IRIS rgb image
    writeimage /usr/tmp/__temp.rgb 
    exec tobw /usr/tmp/__temp.rgb ${name}${suffix}.rgb
}

proc writejpgframe {name count} {

    # Set up frame count suffix
    if {$count < 10} {
	set suffix 000${count}
    } elseif {$count < 100} {
	set suffix 00${count}
    } elseif {$count < 1000} {
	set suffix 0${count}
    } else {
	set suffix ${count}
    }

    # Write out IRIS rgb image
    writeimage /usr/tmp/__temp.rgb

    # Write out IRIS rgb image
    exec tojpg -q 90 /usr/tmp/__temp.rgb ${name}${suffix}.jpg
}

alias rotmesh plv_rotmesh
alias rotview plv_rotview
alias transview plv_transview

proc rotview {axis angle} {
    global theOglwinNormal

    plv_rotview $axis $angle
}

proc writeimage {filename} {
    global theOglwinNormal

    plv_writeiris $theOglwinNormal $filename
}

proc writeimage2 {filename} {
    global theOglwinNormal

    set photo [image create photo tempPhoto]
    plv_fillphoto $theOglwinNormal $photo
    $photo write $filename -format ppm
    image delete $photo
}


proc antiAliasDraw {} {
    global theOglwinNormal

    plv_drawstyle -antialias 1
    plv_draw $theOglwinNormal
    plv_drawstyle -antialias 0
}

proc redraw {} {
    global theOglwinNormal

    plv_draw $theOglwinNormal
}


proc writeply args {

    global meshFrame

    set len [llength args]
    if {$len < 1 || $len > 2} {
	puts "writeply: wrong number of args"
	return
    }

    set meshName [lindex $args 0]
    set names [array names meshFrame]
    set meshExists [lsearch $names $meshName]

    if {$meshExists < 0} {
	puts "writeply: mesh not found"
	return
    }


    if {[llength $args] > 1} {
	set filename [lindex $args 1]
    } else {
	set filename $meshName
    }

    set filelist $filename

    set root [file rootname $filename]
    set ext [file extension $filename]
    set i 2
    for {set i 2} {$i <= 4} {incr i} {
        set nextName ${root}_res${i}${ext}
        lappend filelist $nextName
    }

    set filesExist 0
    foreach x $filelist {
	if {[file readable $x]} {
	    set filesExist 1
	}	
    }
    
    if {$filesExist} {
	puts ""
	puts -nonewline "File(s) already exist.  OK to overwrite? (y/n) "
	flush stdout
	gets stdin doit
	if {!($doit == "y")} {
	    puts "No files written."
	    return
	}
	
    }

    set command [concat plv_writeply $meshName 4 $filelist]

    eval $command    
}


proc readcyb args {
    global theOglwinNormal

    set name [lindex $args 0]

    if {[lindex $args 1] == "-head"} {
	plv_param -maxlen 100
    }

    if {![file readable $name]} {
        puts "Could not read file $name."
        return
    }

    set cybTextureName ${name}.color
    set finalTextureName ${name}.rgb

    if {![file readable $cybTextureName] && \
	    ![file readable $finalTextureName]} {
	set noTexture 1
    } else {
	set noTexture 0
    }

    if {[file readable $finalTextureName]} {
	set time1 [file mtime $name]
	set time2 [file mtime $finalTextureName]
	if {$time1 > $time2} {
	    set makeNewTexture 1
	} else {
	    set makeNewTexture 0
	}
    } else {
	set makeNewTexture 1
    }
    
    if {$noTexture} {
	plv_readcyb $name
    } elseif {!$makeNewTexture} {
	plv_readcyb $name -tex $finalTextureName
    } else {
	puts "Creating new texture map $finalTextureName..."

	if {1} {

	    # All of this attempts to make up for crummy color 
	    # from standard ee from the MS platform

	    exec iflip $cybTextureName /usr/tmp/__temp.rgb 90	
	    exec chmod 666 /usr/tmp/__temp.rgb
	    exec /usr/graphics/bin/fixcybcolor \
		    /usr/tmp/__temp.rgb /usr/tmp/__temp2.rgb 
	    exec chmod 666 /usr/tmp/__temp2.rgb
	    exec greyscale /usr/tmp/__lin7.bw 1 7 10
	    exec chmod 666 /usr/tmp/__lin7.bw
	    exec convolve /usr/tmp/__temp2.rgb /usr/tmp/__temp.rgb /usr/tmp/__lin7.bw
	    exec hipass3 /usr/tmp/__temp.rgb /usr/tmp/__temp2.rgb 0.35
	    exec iflip /usr/tmp/__temp2.rgb $finalTextureName 180
	    exec rm /usr/tmp/__temp.rgb
	    exec rm /usr/tmp/__temp2.rgb

	} else {

	    # All of this attempts to make up for crummy color 
	    # from standard ee from the PS platform

	    exec iflip $cybTextureName /usr/tmp/__temp.rgb 270	
	    exec chmod 666 /usr/tmp/__temp.rgb
	    exec /usr/graphics/bin/fixcybcolor \
		    /usr/tmp/__temp.rgb $finalTextureName
	    exec rm /usr/tmp/__temp.rgb
	}

	plv_readcyb $name -tex $finalTextureName
    }

    addMeshToWindow $name

    plv_draw $theOglwinNormal
}


proc readply args {

    global theOglwinNormal

    set name [lindex $args 0]

    if {![file readable $name]} {
        puts "Could not read file $name."
        return
    }

    set filelist $name

    set root [file rootname $name]
    set ext [file extension $name]
    set i 2
    while {1} {
        set nextName ${root}_res${i}${ext}
        if {![file readable $nextName]} {
            break
	}
        lappend filelist $nextName
        incr i
    }

    if {[llength $filelist] > 1} {
	set file1 [lindex $filelist 0]
	set file2 [lindex $filelist 1]
	set time1 [file mtime $file1]
	set time2 [file mtime $file2]
	if {$time1 > $time2} {
	    puts ""
	    puts "$file1 is newer than $file2."
	    puts "Will not use existing multi-res."
	    set filelist $file1
	}
    }

    set isRangeGrid [plv_israngegrid $name]

    if {[llength $filelist] < 4 && !$isRangeGrid} {
	puts ""
	puts -nonewline "Multiresolution is incomplete.  Generate? (y/n) "
	flush stdout
	gets stdin doit
	puts ""
	if {($doit == "y")} {
	    set last [lindex $filelist end]
	    set index [expr [llength $filelist] + 1]
	    while {$index <= 4} {
		set next ${root}_res${index}${ext}
		puts "Generating $next..."
		catch [exec /u/curless/bin/plycrunch < $last > $next] msg
		set last $next
		lappend filelist $last
		incr index
	    }
	}
    }

    set command [concat plv_readply [llength $filelist] $filelist \
	    [lrange $args 1 end]]


    puts "Reading meshes..."
    eval $command

#    eval "plv_readply [llength $filelist] $filelist"

    addMeshToWindow $name

    plv_draw $theOglwinNormal
}


proc addMeshToWindow {name} {
    global leftFrame
    global meshFrame
    global meshVisible
    global theMesh

    set names [array names meshFrame]
    foreach x $names {lappend taken $meshFrame($x)}
    set i 0
    while {[lsearch $taken $leftFrame.meshFrame$i] >= 0} {incr i}
    set meshFrame($name) [frame $leftFrame.meshFrame$i]

    set meshLabel [label $meshFrame($name).label -text $name]
    set radioMove [radiobutton $meshFrame($name).radioMove -variable theMover \
                   -value $name -command [list prepareMoveMesh $name]]
    set meshVisible($name) 1

    set checkVis [checkbutton $meshFrame($name).checkVis \
	    -variable meshVisible($name) \
	    -command [list changeVis $name]]

    pack $radioMove $checkVis $meshLabel -side right -anchor e
    pack $meshFrame($name) -side top -anchor e
}



proc changeVis {name} {
    global meshVisible
    global theOglwinNormal

    plv_setvis $name $meshVisible($name)
    plv_draw $theOglwinNormal
}


proc copyToClipMesh {} {
    global theOglwinNormal
    global clipEnabled
    global meshVisible

    if {!$clipEnabled} {
	puts "No clip box specified."
	return
    }

    set visible [getVisibleMeshes]

    if {[llength $visible] > 1} {
	puts "Too many visible meshes.  One at a time!"
	return
    }

    set meshName [lindex $visible 0]
    plv_copybox $meshName

    set meshVisible($meshName) 0
    set meshVisible(ClipMesh) 1

    changeVis $meshName
    changeVis ClipMesh

    plv_draw $theOglwinNormal

    clearClip
}


proc doFullClip {} {
    global theOglwinNormal
    global clipEnabled

    if {!$clipEnabled} {
	puts "No clip box specified."
	return
    }

    plv_clipbox

    plv_draw $theOglwinNormal

    clearClip
}


proc clearClip {} {
    global theOglwinOverlay
    global clipEnabled
    global env


    if {$env(HOSTTYPE) != "i386-linux"} {    
	plv_clearov $theOglwinOverlay
    }
    set clipEnabled 0

    return
}


proc getVisibleMeshes {} {
    global meshVisible

    set names [array names meshVisible]
    foreach x $names {
	if {$meshVisible($x)} {	    
	    lappend visible $x
	}
    }

    return $visible
}



proc prepareMoveMesh {name} {
    global theOglwinNormal
    global theOglwinOverlay
    global theMesh

    set theMesh $name

    bind $theOglwinOverlay <ButtonPress-1> \
	    {plv_rotxymeshmouse $theOglwinNormal $theMesh %x %y start}
    bind $theOglwinOverlay <B1-Motion> \
	    {plv_rotxymeshmouse $theOglwinNormal $theMesh %x %y}

    bind $theOglwinOverlay <Shift-ButtonPress-1> \
	    {plv_rotymeshmouse $theOglwinNormal $theMesh %x %y start}
    bind $theOglwinOverlay <Shift-B1-Motion> \
	    {plv_rotymeshmouse $theOglwinNormal $theMesh %x %y}
    

    bind $theOglwinOverlay <ButtonPress-2> \
	    {plv_settransxyscale $theOglwinNormal %x %y $theMesh; \
             plv_transxymeshmouse $theOglwinNormal $theMesh %x %y start}
    bind $theOglwinOverlay <B2-Motion> \
	    {plv_transxymeshmouse $theOglwinNormal $theMesh %x %y}

    bind $theOglwinOverlay <Shift-ButtonPress-2> \
	    {plv_rotxmeshmouse $theOglwinNormal $theMesh %x %y start}
    bind $theOglwinOverlay <Shift-B2-Motion> \
	    {plv_rotxmeshmouse $theOglwinNormal $theMesh %x %y}
    

    bind $theOglwinOverlay <ButtonPress-3> \
	    {plv_settranszscale $theOglwinNormal %x %y $theMesh; \
	    plv_transzmeshmouse $theOglwinNormal $theMesh %x %y start}
    bind $theOglwinOverlay <B3-Motion> \
	    {plv_settranszscale $theOglwinNormal %x %y $theMesh; \
	    plv_transzmeshmouse $theOglwinNormal $theMesh %x %y}


#    bind $theOglwinOverlay <ButtonPress-3> \
#	    {plv_transzmesh $theOglwinNormal $theMesh %x %y start}
#    bind $theOglwinOverlay <B3-Motion> \
#	    {plv_transzmesh $theOglwinNormal $theMesh %x %y}


    bind $theOglwinOverlay <Shift-ButtonPress-3> \
	    {plv_rotzmeshmouse $theOglwinNormal $theMesh %x %y start}
    bind $theOglwinOverlay <Shift-B3-Motion> \
	    {plv_rotzmeshmouse $theOglwinNormal $theMesh %x %y}
    
}


proc prepareMoveViewer {} {
    global theOglwinNormal
    global theOglwinOverlay

    bind $theOglwinOverlay <ButtonPress-1> \
	    {plv_rotxyviewmouse $theOglwinNormal %x %y start}
    bind $theOglwinOverlay <B1-Motion> \
	    {plv_rotxyviewmouse $theOglwinNormal %x %y}

    bind $theOglwinOverlay <Shift-ButtonPress-1> \
	    {plv_rotyviewmouse $theOglwinNormal %x %y start}
    bind $theOglwinOverlay <Shift-B1-Motion> \
	    {plv_rotyviewmouse $theOglwinNormal %x %y}
    

    bind $theOglwinOverlay <ButtonPress-2> \
	    {plv_settransxyscale $theOglwinNormal %x %y; \
	    plv_transxyviewmouse $theOglwinNormal %x %y start}
    bind $theOglwinOverlay <B2-Motion> \
	    {plv_transxyviewmouse $theOglwinNormal %x %y}

    bind $theOglwinOverlay <Shift-ButtonPress-2> \
	    {plv_rotxviewmouse $theOglwinNormal %x %y start}
    bind $theOglwinOverlay <Shift-B2-Motion> \
	    {plv_rotxviewmouse $theOglwinNormal %x %y}
    

    bind $theOglwinOverlay <ButtonPress-3> \
	    {plv_settranszscale $theOglwinNormal %x %y; \
	    plv_transzviewmouse $theOglwinNormal %x %y start}
    bind $theOglwinOverlay <B3-Motion> \
	    {plv_settranszscale $theOglwinNormal %x %y; \
	    plv_transzviewmouse $theOglwinNormal %x %y}

#    bind $theOglwinOverlay <ButtonPress-3> \
#	    {plv_transzview $theOglwinNormal %x %y start}
#    bind $theOglwinOverlay <B3-Motion> \
#	    {plv_transzview $theOglwinNormal %x %y}

    bind $theOglwinOverlay <Shift-ButtonPress-3> \
	    {plv_rotzviewmouse $theOglwinNormal %x %y start}
    bind $theOglwinOverlay <Shift-B3-Motion> \
	    {plv_rotzviewmouse $theOglwinNormal %x %y}
    

}


proc setShininess {shiny} {
    if {$shiny} {
        plv_material -shininess 90 -specular 0.25 0.25 0.25
    } else {
        plv_material -specular 0 0 0 
    }
}

proc updateOglwin {normal overlay} {
    global theOglwinNormal
    global theOglwinOverlay
    global lowerFrame
    global theMover

    pack forget $theOglwinNormal
    pack forget $lowerFrame
    set theOglwinNormal $normal
    set theOglwinOverlay $overlay

    setBindings

    pack $theOglwinNormal -expand 1 -fill both
    pack $lowerFrame -side top
    
    if {$theMover == "_viewer_"} {
	prepareMoveViewer
    } else {
	prepareMoveMesh
    }

    # Intended to make for smoother transition, but didn't really help
    plv_clearwin $theOglwinNormal
    update
}


proc singlebuffer {} {
    global theOglwinNormal
    global oglwinSingle
    global oglwinOverlaySingle
    global env

    set isSinglebuffer 1

    if {$env(HOSTTYPE) == "i386-linux"} {    
	updateOglwin $oglwinSingle $oglwinSingle
    } else {
	updateOglwin $oglwinSingle $oglwinOverlaySingle
    }
}


proc doublebuffer {} {
    global theOglwinNormal
    global oglwinDouble
    global oglwinOverlayDouble
    global env

    if {$env(HOSTTYPE) == "i386-linux"} {    
	updateOglwin $oglwinDouble $oglwinDouble
    } else {
	updateOglwin $oglwinDouble $oglwinOverlayDouble
    }
}


proc setBindings {} {
    global theOglwinNormal
    global theOglwinOverlay
    global clipEnabled
    global env

    bind $theOglwinNormal <Configure> {plv_draw $theOglwinNormal}
    bind $theOglwinNormal <Expose> {plv_draw $theOglwinNormal}

    # This doesn't work??
    bind $theOglwinOverlay <Escape> {exit}

    # This works
    bind all <Escape> {exit}

    bind $theOglwinOverlay <Control-ButtonPress-1> \
	    {plv_rotlight $theOglwinNormal %x %y}
    bind $theOglwinOverlay <Control-B1-Motion> \
	    {plv_rotlight $theOglwinNormal %x %y}

    if {$env(HOSTTYPE) == "i386-linux"} {    
	bind $theOglwinOverlay <Alt-ButtonPress-1> \
		{plv_nodrawovbox $theOglwinOverlay %x %y start}
	bind $theOglwinOverlay <Alt-B1-Motion> \
		{set clipEnabled 1; \
		plv_nodrawovbox $theOglwinOverlay %x %y}
    } else {
	bind $theOglwinOverlay <Alt-ButtonPress-1> \
		{plv_drawovbox $theOglwinOverlay %x %y start}
	bind $theOglwinOverlay <Alt-B1-Motion> \
		{set clipEnabled 1; \
		plv_drawovbox $theOglwinOverlay %x %y}
    }
}
    


set leftButtons [toplevel .leftButtons]

set leftFrame [frame $leftButtons.leftFrame]

set viewFrame [frame $leftFrame.viewFrame]
set viewLabel [label $viewFrame.label -text "Viewer"]
set viewMove [radiobutton $viewFrame.radioMove -variable theMover \
	-value _viewer_ -command {prepareMoveViewer}]

pack $viewLabel $viewMove -side left -anchor e
pack $viewFrame -side top -anchor e

pack $leftFrame -side right


set renderWindow [toplevel .renderWindow]

if {$env(HOSTTYPE) == "i386-linux"} {
    set oglwinDouble [oglxwin $renderWindow.oglwinDouble \
                      -doublebuffer 1 -rgbmode 1 -zbuffer 1 -accum 1] 
    set oglwinSingle [oglxwin $renderWindow.oglwinSingle -doublebuffer 0 \
	    -rgbmode 1 -zbuffer 1 -accum 1]
    set theOglwinNormal $oglwinDouble
    set theOglwinOverlay $oglwinDouble
#    pack $oglwinDouble -expand 1 -fill both
} else {
    set oglwinDouble [oglxwin $renderWindow.oglwinDouble \
                      -doublebuffer 1 -rgbmode 1 -zbuffer 1 -accum 1] 

    # Trying to make transition between sb/db fast on first try
    # no good
    pack $oglwinDouble -expand 1 -fill both
    pack forget $oglwinDouble

    set oglwinOverlayDouble [oglxwin $oglwinDouble.overlay -overlay 1 ]
    pack $oglwinOverlayDouble -expand 1 -fill both

    set oglwinSingle [oglxwin $renderWindow.oglwinSingle -doublebuffer 0 \
	    -rgbmode 1 -zbuffer 1 -accum 1]

    # Trying to make transition between sb/db fast on first try
    # no good
    pack $oglwinSingle -expand 1 -fill both
    pack forget $oglwinSingle

    set oglwinOverlaySingle [oglxwin $oglwinSingle.overlay -overlay 1]
    pack $oglwinOverlaySingle -expand 1 -fill both

    set theOglwinNormal $oglwinDouble
    set theOglwinOverlay $oglwinOverlayDouble
}

pack $theOglwinNormal -expand 1 -fill both

# Broken on linux...shouldn't be
#oglxwin .test -indexmode 1

#updateOglwin $oglwinDouble

set bottomWindow [toplevel .bottomWindow]

set lowerFrame [frame $bottomWindow.lowerFrame]

set meshResFrame [frame $lowerFrame.resFrame]

set radioRes1 [radiobutton $meshResFrame.radioRes1 -text "Mesh1" \
               -variable theMeshResolution -value 0 \
               -command {plv_resolution $theMeshResolution; 
                         plv_draw $theOglwinNormal}]

set radioRes2 [radiobutton $meshResFrame.radioRes2 -text "Mesh2" \
               -variable theMeshResolution -value 1 \
               -command {plv_resolution $theMeshResolution; \
                         plv_draw $theOglwinNormal}]

set radioRes3 [radiobutton $meshResFrame.radioRes3 -text "Mesh3" \
               -variable theMeshResolution -value 2 \
               -command {plv_resolution $theMeshResolution; \
                         plv_draw $theOglwinNormal}]

set radioRes4 [radiobutton $meshResFrame.radioRes4 -text "Mesh4" \
               -variable theMeshResolution -value 3 \
               -command {plv_resolution $theMeshResolution; \
                         plv_draw $theOglwinNormal}]

pack $radioRes1 $radioRes2 $radioRes3 $radioRes4 -side top


set polyModeFrame [frame $lowerFrame.polyModeFrame]

set radioPoly [radiobutton $polyModeFrame.radioPoly -text "Polygons" \
               -variable thePolygonMode -value fill \
               -command {plv_drawstyle -polymode fill; \
                         plv_draw $theOglwinNormal}]

set radioWire [radiobutton $polyModeFrame.radioWire -text "Wireframe" \
               -variable thePolygonMode -value line \
               -command {plv_drawstyle -polymode line; \
                         plv_draw $theOglwinNormal}]

set radioPoints [radiobutton $polyModeFrame.radioPoints -text "Points" \
                 -variable thePolygonMode -value point \
                 -command {plv_drawstyle -polymode point; \
                         plv_draw $theOglwinNormal}]

pack $radioPoly $radioWire $radioPoints -side top -anchor w



set materialFrame1 [frame $lowerFrame.matFrame]

set checkShade [checkbutton $materialFrame1.checkShade -text "Smooth" \
               -variable theShadeModel -onvalue smooth -offvalue flat \
               -command {plv_drawstyle -shademodel $theShadeModel; \
                         plv_draw $theOglwinNormal}]

set checkShiny [checkbutton $materialFrame1.checkShiny \
	-text "Shiny" \
	-variable theShinyMode \
	-command {setShininess $theShinyMode; \
	plv_draw $theOglwinNormal}]

set checkEmissive [checkbutton $materialFrame1.checkEmissive \
	-text "Emissive" \
	-variable theEmissiveMode \
	-command {plv_drawstyle -emissive $theEmissiveMode; \
	plv_draw $theOglwinNormal}]

set checkCull [checkbutton $materialFrame1.checkCull \
	-text "Backface cull" \
	-variable theCullMode \
	-command {plv_drawstyle -cull $theCullMode; \
	plv_draw $theOglwinNormal}]

set checkFlipNormal [checkbutton $materialFrame1.checkFlipNormal \
	-text "Flip normals" \
	-variable theFlipNormalMode \
	-command {plv_drawstyle -flipnorm $theFlipNormalMode; \
	plv_draw $theOglwinNormal}]

pack $checkShade $checkShiny $checkEmissive $checkCull $checkFlipNormal \
	-side top -anchor w


set materialFrame2 [frame $lowerFrame.matFrame2]

set radioGrayColor [radiobutton $materialFrame2.radioGrayColor \
	-text "Gray color" \
	-variable theColorMode \
	-value "graycolor" \
	-command {plv_material -confidence 0 -truecolor 0 -falsecolor 0 -texture 0; \
	plv_draw $theOglwinNormal}]

set radioFalseColor [radiobutton $materialFrame2.radioFalseColor \
	-text "False color" \
	-variable theColorMode \
	-value "falsecolor" \
	-command {plv_material -confidence 0 -truecolor 0 -falsecolor 1 -texture 0; \
	plv_draw $theOglwinNormal}]

set radioTrueColor [radiobutton $materialFrame2.checkTrueColor \
	-text "True color"  \
	-variable theColorMode \
	-value "truecolor" \
	-command {plv_material -confidence 0 -truecolor 1 -falsecolor 0 -texture 0; \
	plv_draw $theOglwinNormal}]

set radioConfidence [radiobutton $materialFrame2.checkConfidence \
	-text "Confidence"  \
	-variable theColorMode \
	-value "confidence" \
	-command {plv_material -confidence 1 -truecolor 0 -falsecolor 0 -texture 0; \
	plv_draw $theOglwinNormal}]

set radioTexture [radiobutton $materialFrame2.checkTexture \
	-text "Texture"  \
	-variable theColorMode \
	-value "texture" \
	-command {plv_material -confidence 0 -truecolor 0 -falsecolor 0 -texture 1; \
	plv_draw $theOglwinNormal}]

pack $radioGrayColor $radioFalseColor $radioTrueColor $radioConfidence \
	$radioTexture -side top -anchor w


set clipFrame [frame $lowerFrame.clipFrame]

set viewAllButton [button $clipFrame.viewAllButton \
	-text "View all" -command {plv_viewall $theOglwinNormal}]
set copyButton [button $clipFrame.copyButton \
	-text "Do clip" -command {copyToClipMesh}]
set clearClipButton [button $clipFrame.clearClipButton \
	-text "Clear clip" -command {clearClip}]
set fullClipButton [button $clipFrame.fullClipButton \
	-text "Full clip" -command {doFullClip}]

pack $viewAllButton $copyButton $clearClipButton $fullClipButton \
	-side top -anchor w -expand 1 -fill x


set viewStyleFrame [frame $lowerFrame.viewStyleFrame]

set checkOrtho [checkbutton $viewStyleFrame.checkOrtho \
	-text "Orthographic" \
	-variable isOrthographic \
	-command {if {$isOrthographic} {plv_ortho} else {plv_persp}; \
	plv_draw $theOglwinNormal}]

set checkSinglebuffer [checkbutton $viewStyleFrame.checkSinglebuffer \
	-text "Singlebuffer" \
	-variable isSinglebuffer \
	-command {if {$isSinglebuffer} {singlebuffer} else {doublebuffer}}]

set antiAliasButton [button $viewStyleFrame.anitAliasButton \
	-text "Anti-alias" -command {antiAliasDraw}]

pack $checkOrtho $checkSinglebuffer $antiAliasButton -side top -anchor w


pack $viewStyleFrame $clipFrame $materialFrame2 $materialFrame1 \
	$polyModeFrame $meshResFrame -side left

pack $lowerFrame -side top


wm withdraw .
wm title $leftButtons "Selection"
#wm group $leftButtons $renderWindow $bottomWindow
wm resizable $leftButtons 0 0
wm title $renderWindow plyview
wm title $bottomWindow Options

if {$env(HOSTTYPE) == "i386-linux"} {
    wm geometry $leftButtons +250+50
    wm geometry $renderWindow 500x461+420+50
    wm geometry $bottomWindow 500x120+420+550
} else {
    wm geometry $leftButtons +320+100
    wm geometry $renderWindow 730x661+516+50
    wm geometry $bottomWindow 730x143+516+750
}


#pack $theOglwin -expand 1 -fill both


addMeshToWindow "ClipMesh"
set meshVisible(ClipMesh) 0


bind $renderWindow <Unmap> {wm withdraw $leftButtons; wm withdraw $bottomWindow}
bind $renderWindow <Map> {wm deiconify $leftButtons; wm deiconify $bottomWindow}

alias bmesh readply
alias mesh readcyb
alias quit exit

proc mesh args {}
proc camera args {}

setShininess 1

update

plv_draw $theOglwinNormal
setBindings
prepareMoveViewer

